#!/bin/sh

# NAME:
#	exec-shell - create a wrapper to exec scripts with a specific shell
#
# SYNOPSIS:
#	exec-shell.sh ["var"="val"] "script"
#
# DESCRIPTION:
#	We create a wrapper "os"/"target" and make symlinks to it
#	for each "script".  The wrapper will exec the real "script"
#	with the specified "shell".  The real "script" is found by
#	removing "os"/ from the name we were invoked with.
#
#	The defaults depend on the OS we run on.  For SunOS, "shell"
#	defaults to '/usr/xpg4/bin/sh', on HP-UX it is '/bin/ksh'.
#
#	You can actually setup wrappers for languages other than shell
#	scripts.
#
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: exec-shell.sh,v 1.3 2010/01/05 16:33:12 sjg Exp $
#
#	@(#) Copyright (c) 2009 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Mydir=`dirname $0`
Myname=`basename $0 .sh`

case $Mydir in
.*) Mydir=`cd $Mydir && 'pwd'`;;
esac
. $Mydir/os.sh

os=`echo $OS | toLower`
shell=
target=

while :
do
	case "$1" in
	*=*) eval "$1"; shift;;
	*) break;;
	esac
done

case "$os" in
sunos) shell=${shell:-/usr/xpg4/bin/sh};;
hp-ux) shell=${shell:-/bin/ksh};;
*) 
	for sh in /usr/xpg4/bin/sh /bin/ksh /bin/bash
	do
		[ -x $sh ] || continue
		shell=${shell:-$sh}
		break
	done
	;;
esac

shell=${shell:-/bin/sh}
target=${target:-$Myname}

case "$script_shell" in
/bin/sh) echo "$os: $shell: no need for $target ?"; exit 0;;
esac

osdir=${osdir:-$Mydir/$os}
wrapper=$osdir/$target
if [ ! -x $wrapper ]; then
	mkdir -p $osdir
	cat <<!EOS > $wrapper
#!/bin/sh
script=\`echo \$0 | sed 's,$os/,,'\`
exec $shell \$script "\$@"
!EOS
	chmod +x $wrapper
fi
echo Using $wrapper
for t in "$@"
do
	tb=`basename $t`
	ts=$osdir/$tb
	[ -x $ts ] && continue
	tt=`echo $ts | sed "s,$os/,,"`
	[ -x $tt ] || { echo $tt: no such thing; continue; }
	ln -s $target $ts
done
