/*
 * NAME:
 *	sslpw - routines useful for SSL servers and clients
 *
 * SYNOPSIS:
 *	int ssl_get_pw(const char *"key_file", int "log_lev")
 *	
 * DESCRIPTION:
 *	
 * SEE ALSO:
 *	sslfd(3), ssld(3), sslc(3), ssl_rcmd(3), netio(3).
 *
 * AUTHOR:
 *	Simon J. Gerraty <sjg@crufty.net>
 */
/*
 *	@(#)Copyright (c) 1996 Simon J. Gerraty.
 *	
 *	This is free software.	It comes with NO WARRANTY.
 *	Permission to use, modify and distribute this source code 
 *	is granted subject to the following conditions.
 *	1/ that the above copyright notice and this notice 
 *	are preserved in all copies and that due credit be given 
 *	to the author.	
 *	2/ that any changes to this code are clearly commented 
 *	as such so that the author does not get blamed for bugs 
 *	other than his own.
 *	
 *	Please send copies of changes and bug-fixes to:
 *	sjg@crufty.net
 */
#ifndef lint
static char RCSid[] = "$Id: sslpw.c,v 1.3 2002/12/13 23:08:33 sjg Exp $";
#endif

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#include <stdio.h>
#if defined(HAVE_STDLIB_H)
#include <stdlib.h>
#endif
#include <sys/types.h>
#if defined(HAVE_SYSLOG_H)
#include <syslog.h>
#endif
#include <string.h>
#if defined(HAVE_UNISTD_H)
#include <unistd.h>
#endif

#include "ssl.h"
#include "sslfd.h"

/*
 * this is mainly here for telnet's use
 */
int
ssl_get_pw(key_file, log_lev)
	const char *key_file;
	int log_lev;
{
	if (!key_file)
		key_file = ssl_key_file;
	
	if (key_file && *key_file) {
		if (SSL_use_RSAPrivateKey_file(ssl_con,
					       (char *) key_file,
					       X509_FILETYPE_PEM)<=0) {
			ssl_err(log_lev, "SSL_use_RSAPrivateKey_file error %s\n");
			return (-1);
		}
		if (key_file == ssl_key_file) {
			free(ssl_key_file);
			ssl_key_file = 0;
		}
	}
	return 0;
}
